==> py22-numarray-0.3.4.tbz: share/examples/py-numarray/convolve/convolve_test.py <==
# numarray convolve-example tests
#
# Do not run this file directly, it is used from convtest.py

import numarray
import sys
import unittest

array = numarray.array
Float64 = numarray.Float64
Int32 = numarray.Int32


# some helper functions used in the tests

def dotest(f, k, x, z=None):
    kref = sys.getrefcount(k)
    xref = sys.getrefcount(x)
    zref = sys.getrefcount(z)
    if z is None:
        c = f(k, x)
    else:
        c = f(k, x, z)
    assert(sys.getrefcount(k) == kref)
    assert(sys.getrefcount(x) == xref)
    if z is None:
        assert(sys.getrefcount(c) == 2)
    else:
        assert(sys.getrefcount(z) == zref)
    return c or z

def conv1(k, x, z=None):
    return dotest(convolve.Convolve1d, k, x, z)
    
def conv2(k, x, z=None):
    return dotest(convolve.Convolve2d, k, x, z)

def test():
    import doctest, convtest
    return doctest.testmod(convtest)



# actual test-class

class convolve_test(unittest.TestCase):

    def test_001(self):
        """Unconverted data, unconverted output."""
        self.failIf(
            conv1(numarray.array([1.,2.,1.]), numarray.arange(10.),
                  numarray.zeros((10,), type=Float64)).__ne__(
            array([0., 4., 8., 12., 16., 20., 24., 28., 32., 9.])))

    def test_002(self):
        """Converted data, unconverted output."""
        self.failIf(
            conv1(numarray.array([1.,2.,1.]), numarray.arange(10),
                  numarray.zeros((10,), type=Float64)).__ne__(
            array([0, 4, 8, 12, 16, 20, 24, 28, 32, 9])))

    def test_003(self):
        """Unconverted data, converted output."""
        self.failIf(
            conv1(numarray.array([1.,2.,1.]), numarray.arange(10.),
                  numarray.zeros((10,), type=Int32)).__ne__(
            array([0, 4, 8, 12, 16, 20, 24, 28, 32, 9])))

    def test_004(self):
        """Converted data, converted output."""
        self.failIf(
            conv1(numarray.array([1.,2.,1.]), numarray.arange(10.),
                  numarray.zeros((10,), type=Int32)).__ne__(
            array([0, 4, 8, 12, 16, 20, 24, 28, 32, 9])))

    def test_005(self):
        """Converted data, no output."""
        self.failIf(conv1(numarray.array([1.,2.,1.]), numarray.arange(10.),
                  numarray.zeros((10,), type=Int32)).__ne__(
            array([0., 4., 8., 12., 16., 20., 24., 28., 32., 9.])))

    def test_006(self):
        """Unonverted data, no output."""
        self.failIf(
            conv1(numarray.array([1.,2.,1.]), numarray.arange(10),
                  numarray.zeros((10,), type=Int32)).__ne__(
            array([0., 4., 8., 12., 16., 20., 24., 28., 32., 9.])))

    def test_007(self):
        """List data, no output."""
        self.failIf(
            conv1([1.,2.,1.], numarray.arange(10),
                  numarray.zeros((10,), type=Int32)).__ne__(
            array([0., 4., 8., 12., 16., 20., 24., 28., 32., 9.])))

    def test_008(self):
        """Byteswapped data, no output."""
        a = numarray.array([1.,2.,1.])
        a._byteswap = 1
        a.byteswap()
        self.failIf(
            conv1(a, range(10),
                  numarray.zeros((10,), type=Float64)).__ne__(
            array([0., 4., 8., 12., 16., 20., 24., 28., 32., 9.])))
        
    def test_008(self):
        """Byteswapped data, no output."""
        a = numarray.array([1.,2.,1.])
        a._aligned = 1
        self.failIf(conv1(a, range(10),
                          numarray.zeros((10,), type=Float64)).__ne__(
            array([0., 4., 8., 12., 16., 20., 24., 28., 32., 9.])))
        
    def test_101(self):
        """2d convolve 10x10 by 5,5."""
        x = numarray.zeros((10,10), numarray.Float64) + 1
        k = numarray.zeros((5,5), numarray.Float64) + 0.25
        k[1:4,1:4] = 0.5
        k[2,2] = 1
        z = numarray.zeros((10,10), numarray.Float64)
        self.failIf(conv2(k, x, z).__ne__(
            array([[ 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.],
                   [ 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.],
                   [ 1., 1., 9., 9., 9., 9., 9., 9., 1., 1.],
                   [ 1., 1., 9., 9., 9., 9., 9., 9., 1., 1.],
                   [ 1., 1., 9., 9., 9., 9., 9., 9., 1., 1.],
                   [ 1., 1., 9., 9., 9., 9., 9., 9., 1., 1.],
                   [ 1., 1., 9., 9., 9., 9., 9., 9., 1., 1.],
                   [ 1., 1., 9., 9., 9., 9., 9., 9., 1., 1.],
                   [ 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.],
                   [ 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.]])))
                    


class NoExitTestProgram(unittest.TestProgram):
    """A command-line program that runs a set of tests; this is primarily
       for making test modules conveniently executable.

       Does not exit explicitely!
    """
    def runTests(self):
        if self.testRunner is None:
            self.testRunner = TextTestRunner(verbosity=self.verbosity)
        result = self.testRunner.run(self.test)
        return(not result.wasSuccessful())

from unittest import *
NoExitTestProgram()

==> py22-numarray-0.5.tbz: share/examples/py-numarray/convolve/convolve_test.py <==
# numarray convolve-example tests
#
# Do not run this file directly, it is used from convtest.py

import numarray
import sys
import unittest

array = numarray.array
Float64 = numarray.Float64
Int32 = numarray.Int32


# some helper functions used in the tests

def dotest(f, k, x, z=None):
    kref = sys.getrefcount(k)
    xref = sys.getrefcount(x)
    zref = sys.getrefcount(z)
    if z is None:
        c = f(k, x)
    else:
        c = f(k, x, z)
    assert(sys.getrefcount(k) == kref)
    assert(sys.getrefcount(x) == xref)
    if z is None:
        assert(sys.getrefcount(c) == 2)
    else:
        assert(sys.getrefcount(z) == zref)
    if c is not None:
        return c
    else:
        return z

def conv1(k, x, z=None):
    return dotest(convolve.Convolve1d, k, x, z)
    
def conv2(k, x, z=None):
    return dotest(convolve.Convolve2d, k, x, z)

def test():
    import doctest, convtest
    return doctest.testmod(convtest)



def logical_reduce(a):
    return numarray.logical_and.reduce(numarray.ravel(a))

# actual test-class

class convolve_test(unittest.TestCase):

    def _FailIf(self, x):
        return self.failIf( logical_reduce(x) )

    def test_001(self):
        """Unconverted data, unconverted output."""
        self._FailIf(
            conv1(numarray.array([1.,2.,1.]), numarray.arange(10.),
                  numarray.zeros((10,), type=Float64)).__ne__(
            array([0., 4., 8., 12., 16., 20., 24., 28., 32., 9.])))

    def test_002(self):
        """Converted data, unconverted output."""
        self._FailIf(
            conv1(numarray.array([1.,2.,1.]), numarray.arange(10),
                  numarray.zeros((10,), type=Float64)).__ne__(
            array([0, 4, 8, 12, 16, 20, 24, 28, 32, 9])))

    def test_003(self):
        """Unconverted data, converted output."""
        self._FailIf(
            conv1(numarray.array([1.,2.,1.]), numarray.arange(10.),
                  numarray.zeros((10,), type=Int32)).__ne__(
            array([0, 4, 8, 12, 16, 20, 24, 28, 32, 9])))

    def test_004(self):
        """Converted data, converted output."""
        self._FailIf(
            conv1(numarray.array([1.,2.,1.]), numarray.arange(10.),
                  numarray.zeros((10,), type=Int32)).__ne__(
            array([0, 4, 8, 12, 16, 20, 24, 28, 32, 9])))

    def test_005(self):
        """Converted data, no output."""
        self._FailIf(conv1(numarray.array([1.,2.,1.]), numarray.arange(10.)).__ne__(
            array([0., 4., 8., 12., 16., 20., 24., 28., 32., 9.])))

    def test_006(self):
        """Unonverted data, no output."""
        self._FailIf(
            conv1(numarray.array([1.,2.,1.]), numarray.arange(10)).__ne__(
            array([0., 4., 8., 12., 16., 20., 24., 28., 32., 9.])))

    def test_007(self):
        """List data, no output."""
        self._FailIf(
            conv1([1.,2.,1.], numarray.arange(10)).__ne__(
            array([0., 4., 8., 12., 16., 20., 24., 28., 32., 9.])))

    def test_008(self):
        """Byteswapped data, no output."""
        a = numarray.array([1.,2.,1.])
        a.byteswap()
        self._FailIf(
            conv1(a, range(10)).__ne__(
            array([0., 4., 8., 12., 16., 20., 24., 28., 32., 9.])))
        
    def test_008(self):
        """Misaligned data, no output."""
        a = numarray.array([1.,2.,1.])
        a._aligned = 1
        self._FailIf(conv1(a, range(10)).__ne__(
            array([0., 4., 8., 12., 16., 20., 24., 28., 32., 9.])))
        
    def test_101(self):
        """2d convolve 10x10 by 5,5."""
        x = numarray.zeros((10,10), numarray.Float64) + 1
        k = numarray.zeros((5,5), numarray.Float64) + 0.25
        k[1:4,1:4] = 0.5
        k[2,2] = 1
        z = numarray.zeros((10,10), numarray.Float64)
        self._FailIf(conv2(k, x, z).__ne__(
            array([[ 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.],
                   [ 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.],
                   [ 1., 1., 9., 9., 9., 9., 9., 9., 1., 1.],
                   [ 1., 1., 9., 9., 9., 9., 9., 9., 1., 1.],
                   [ 1., 1., 9., 9., 9., 9., 9., 9., 1., 1.],
                   [ 1., 1., 9., 9., 9., 9., 9., 9., 1., 1.],
                   [ 1., 1., 9., 9., 9., 9., 9., 9., 1., 1.],
                   [ 1., 1., 9., 9., 9., 9., 9., 9., 1., 1.],
                   [ 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.],
                   [ 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.]])))
                    


class NoExitTestProgram(unittest.TestProgram):
    """A command-line program that runs a set of tests; this is primarily
       for making test modules conveniently executable.

       Does not exit explicitely!
    """
    def runTests(self):
        if self.testRunner is None:
            self.testRunner = TextTestRunner(verbosity=self.verbosity)
        result = self.testRunner.run(self.test)
        return(not result.wasSuccessful())

from unittest import *
NoExitTestProgram()
